@@ -17,7 +17,6 @@
 #include <KMessageBox>
 #include <QMenu>
 #include <QTreeView>
-#include <kwidgetsaddons_version.h>
 
 using namespace ContactEditor;
 
@@ -65,20 +64,12 @@ AddressesLocationWidget::AddressesLocationWidget(QWidget *parent)
         auto action = menu.addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Remove Address"));
         action->setEnabled(!mReadOnly);
         connect(action, &QAction::triggered, this, [this, idx]() {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             const auto result = KMessageBox::questionTwoActions(this,
-#else
-            const auto result = KMessageBox::questionYesNo(this,
-#endif
                                                                 i18n("Do you really want to delete this address?"),
                                                                 QString(),
                                                                 KStandardGuiItem::del(),
                                                                 KStandardGuiItem::cancel());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             if (result == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-            if (result == KMessageBox::Yes) {
-#endif
                 mAddressModel->removeAddress(idx.row());
             }
         });
